@@ -30,6 +30,19 @@
 
 
 
+/**
+ * SECTION: garcon-menu-directory
+ * @title: GarconMenuDirectory
+ * @short_description: Garcon element for .directory files.
+ * @include: garcon/garcon.h
+ *
+ * Element that represents a .directory file in the menu configurations.
+ * Each menu (except for the root menu) has a #GarconMenuDirectory,
+ * see garcon_menu_get_directory().
+ **/
+
+
+
 #define GARCON_MENU_DIRECTORY_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GARCON_TYPE_MENU_DIRECTORY, GarconMenuDirectoryPrivate))
 
 
@@ -60,7 +73,7 @@ enum
   PROP_NAME,
   PROP_COMMENT,
   PROP_NO_DISPLAY,
-  PROP_ICON,
+  PROP_ICON_NAME,
 };
 
 
@@ -89,7 +102,7 @@ struct _GarconMenuDirectoryPrivate
   gchar  *comment;
 
   /* Icon */
-  gchar  *icon;
+  gchar  *icon_name;
 
   /* Environments in which the menu should be displayed only */
   gchar **only_show_in;
@@ -106,6 +119,7 @@ struct _GarconMenuDirectoryPrivate
 
 
 
+/* TODO, maybe implement the GarconMenuElement interface */
 G_DEFINE_TYPE (GarconMenuDirectory, garcon_menu_directory, G_TYPE_OBJECT)
 
 
@@ -166,13 +180,13 @@ garcon_menu_directory_class_init (GarconMenuDirectoryClass *klass)
                                                         G_PARAM_STATIC_STRINGS));
 
   /**
-   * GarconMenuDirectory:icon:
+   * GarconMenuDirectory:icon-name:
    *
    * Icon associated with this directory.
    **/
   g_object_class_install_property (gobject_class,
-                                   PROP_ICON,
-                                   g_param_spec_string ("icon",
+                                   PROP_ICON_NAME,
+                                   g_param_spec_string ("icon-name",
                                                         "Icon",
                                                         "Directory icon",
                                                         NULL,
@@ -203,7 +217,7 @@ garcon_menu_directory_init (GarconMenuDirectory *directory)
   directory->priv = GARCON_MENU_DIRECTORY_GET_PRIVATE (directory);
   directory->priv->file = NULL;
   directory->priv->name = NULL;
-  directory->priv->icon = NULL;
+  directory->priv->icon_name = NULL;
   directory->priv->only_show_in = NULL;
   directory->priv->not_show_in = NULL;
   directory->priv->hidden = FALSE;
@@ -223,8 +237,8 @@ garcon_menu_directory_finalize (GObject *object)
   /* Free comment */
   g_free (directory->priv->comment);
 
-  /* Free icon */
-  g_free (directory->priv->icon);
+  /* Free icon_name */
+  g_free (directory->priv->icon_name);
 
   /* Free environment lists */
   g_strfreev (directory->priv->only_show_in);
@@ -260,8 +274,8 @@ garcon_menu_directory_get_property (GObject    *object,
       g_value_set_string (value, garcon_menu_directory_get_comment (directory));
       break;
 
-    case PROP_ICON:
-      g_value_set_string (value, garcon_menu_directory_get_icon (directory));
+    case PROP_ICON_NAME:
+      g_value_set_string (value, garcon_menu_directory_get_icon_name (directory));
       break;
 
     case PROP_NO_DISPLAY:
@@ -287,7 +301,7 @@ garcon_menu_directory_set_property (GObject      *object,
   switch (prop_id)
     {
     case PROP_FILE:
-      directory->priv->file = g_object_ref (g_value_get_object (value));
+      directory->priv->file = g_value_dup_object (value);
       break;
 
     case PROP_NAME:
@@ -298,8 +312,8 @@ garcon_menu_directory_set_property (GObject      *object,
       garcon_menu_directory_set_comment (directory, g_value_get_string (value));
       break;
 
-    case PROP_ICON:
-      garcon_menu_directory_set_icon (directory, g_value_get_string (value));
+    case PROP_ICON_NAME:
+      garcon_menu_directory_set_icon_name (directory, g_value_get_string (value));
       break;
 
     case PROP_NO_DISPLAY:
@@ -314,6 +328,15 @@ garcon_menu_directory_set_property (GObject      *object,
 
 
 
+/**
+ * garcon_menu_directory_new:
+ * @file : a #GFile
+ *
+ * Create a new #GarconMenuDirectory for @file. You most likely never
+ * use this, but retrieve the info from garcon_menu_get_directory().
+ *
+ * Returns: a #GarconMenuDirectory.
+ **/
 GarconMenuDirectory *
 garcon_menu_directory_new (GFile *file)
 {
@@ -323,7 +346,7 @@ garcon_menu_directory_new (GFile *file)
   GKeyFile            *rc;
   gchar               *name;
   gchar               *comment;
-  gchar               *icon;
+  gchar               *icon_name;
   gboolean             no_display;
   gboolean             succeed;
 
@@ -349,8 +372,8 @@ garcon_menu_directory_new (GFile *file)
                                        G_KEY_FILE_DESKTOP_KEY_NAME, NULL, NULL);
   comment = g_key_file_get_locale_string (rc, G_KEY_FILE_DESKTOP_GROUP,
                                           G_KEY_FILE_DESKTOP_KEY_COMMENT, NULL, NULL);
-  icon = g_key_file_get_locale_string (rc, G_KEY_FILE_DESKTOP_GROUP,
-                                       G_KEY_FILE_DESKTOP_KEY_ICON, NULL, NULL);
+  icon_name = g_key_file_get_string (rc, G_KEY_FILE_DESKTOP_GROUP,
+                                     G_KEY_FILE_DESKTOP_KEY_ICON, NULL);
   no_display = g_key_file_get_boolean (rc, G_KEY_FILE_DESKTOP_GROUP,
                                        G_KEY_FILE_DESKTOP_KEY_NO_DISPLAY, NULL);
 
@@ -359,20 +382,20 @@ garcon_menu_directory_new (GFile *file)
                             "file", file,
                             "name", name,
                             "comment", comment,
-                            "icon", icon,
+                            "icon-name", icon_name,
                             "no-display", no_display,
                             NULL);
 
   /* Free strings */
   g_free (name);
   g_free (comment);
-  g_free (icon);
+  g_free (icon_name);
 
   /* Set rest of the private data directly */
   directory->priv->only_show_in = g_key_file_get_string_list (rc, G_KEY_FILE_DESKTOP_GROUP,
                                                               G_KEY_FILE_DESKTOP_KEY_ONLY_SHOW_IN, NULL, NULL);
   directory->priv->not_show_in = g_key_file_get_string_list (rc, G_KEY_FILE_DESKTOP_GROUP,
-                                                            G_KEY_FILE_DESKTOP_KEY_NOT_SHOW_IN, NULL, NULL);
+                                                             G_KEY_FILE_DESKTOP_KEY_NOT_SHOW_IN, NULL, NULL);
   directory->priv->hidden = g_key_file_get_boolean (rc, G_KEY_FILE_DESKTOP_GROUP,
                                                     G_KEY_FILE_DESKTOP_KEY_HIDDEN, NULL);
 
@@ -386,10 +409,11 @@ garcon_menu_directory_new (GFile *file)
 
 /**
  * garcon_menu_directory_get_file:
+ * @directory : a #GarconMenuDirectory
  *
  * Get the file for @directory.
  *
- * Return value: a #GFile. The returned object
+ * Returns: a #GFile. The returned object
  * should be unreffed with g_object_unref() when no longer needed.
  */
 GFile *
@@ -401,6 +425,14 @@ garcon_menu_directory_get_file (GarconMenuDirectory *directory)
 
 
 
+/**
+ * garcon_menu_directory_get_name:
+ * @directory : a #GarconMenuDirectory
+ *
+ * Get the name of @directory.
+ *
+ * Returns: a the name for @directory.
+ */
 const gchar*
 garcon_menu_directory_get_name (GarconMenuDirectory *directory)
 {
@@ -410,6 +442,13 @@ garcon_menu_directory_get_name (GarconMenuDirectory *directory)
 
 
 
+/**
+ * garcon_menu_directory_set_name:
+ * @directory : a #GarconMenuDirectory
+ * @name : the new name for @directory.
+ *
+ * Set the name of @directory.
+ */
 void
 garcon_menu_directory_set_name (GarconMenuDirectory *directory,
                                 const gchar         *name)
@@ -430,6 +469,14 @@ garcon_menu_directory_set_name (GarconMenuDirectory *directory,
 
 
 
+/**
+ * garcon_menu_directory_get_comment:
+ * @directory : a #GarconMenuDirectory
+ *
+ * Get the comment of @directory.
+ *
+ * Returns: a the description for @directory.
+ */
 const gchar*
 garcon_menu_directory_get_comment (GarconMenuDirectory *directory)
 {
@@ -439,6 +486,13 @@ garcon_menu_directory_get_comment (GarconMenuDirectory *directory)
 
 
 
+/**
+ * garcon_menu_directory_set_comment:
+ * @directory : a #GarconMenuDirectory
+ * @comment : the new description for @directory.
+ *
+ * Set the comment of @directory.
+ */
 void
 garcon_menu_directory_set_comment (GarconMenuDirectory *directory,
                                    const gchar         *comment)
@@ -457,34 +511,59 @@ garcon_menu_directory_set_comment (GarconMenuDirectory *directory,
 }
 
 
+
+/**
+ * garcon_menu_directory_get_icon_name:
+ * @directory : a #GarconMenuDirectory
+ *
+ * Get the icon name of @directory.
+ *
+ * Returns: a the icon-name key for @directory.
+ */
 const gchar*
-garcon_menu_directory_get_icon (GarconMenuDirectory *directory)
+garcon_menu_directory_get_icon_name (GarconMenuDirectory *directory)
 {
   g_return_val_if_fail (GARCON_IS_MENU_DIRECTORY (directory), NULL);
-  return directory->priv->icon;
+  return directory->priv->icon_name;
 }
 
 
 
+/**
+ * garcon_menu_directory_set_icon_name:
+ * @directory : a #GarconMenuDirectory
+ * @icon_name : the new icon name for @directory.
+ *
+ * Set the icon name of @directory.
+ */
 void
-garcon_menu_directory_set_icon (GarconMenuDirectory *directory,
-                                const gchar         *icon)
+garcon_menu_directory_set_icon_name (GarconMenuDirectory *directory,
+                                     const gchar         *icon_name)
 {
   g_return_if_fail (GARCON_IS_MENU_DIRECTORY (directory));
 
   /* Free old name */
-  if (G_UNLIKELY (directory->priv->icon != NULL))
-    g_free (directory->priv->icon);
+  if (G_UNLIKELY (directory->priv->icon_name != NULL))
+    g_free (directory->priv->icon_name);
 
   /* Set the new filename */
-  directory->priv->icon = g_strdup (icon);
+  directory->priv->icon_name = g_strdup (icon_name);
 
   /* Notify listeners */
-  g_object_notify (G_OBJECT (directory), "icon");
+  g_object_notify (G_OBJECT (directory), "icon-name");
 }
 
 
 
+/**
+ * garcon_menu_directory_get_no_display:
+ * @directory : a #GarconMenuDirectory
+ *
+ * Whether @directory should be displayed.
+ * For applications you want to call garcon_menu_directory_get_visible().
+ *
+ * Returns: a the no-display key for @directory.
+ */
 gboolean
 garcon_menu_directory_get_no_display (GarconMenuDirectory *directory)
 {
@@ -494,6 +573,13 @@ garcon_menu_directory_get_no_display (GarconMenuDirectory *directory)
 
 
 
+/**
+ * garcon_menu_directory_set_no_display:
+ * @directory : a #GarconMenuDirectory
+ * @no_display : whether @directory should be displayed.
+ *
+ * Set the NoDisplay key of @directory.
+ */
 void
 garcon_menu_directory_set_no_display (GarconMenuDirectory *directory,
                                       gboolean             no_display)
@@ -513,6 +599,15 @@ garcon_menu_directory_set_no_display (GarconMenuDirectory *directory,
 
 
 
+/**
+ * garcon_menu_directory_get_hidden:
+ * @directory : a #GarconMenuDirectory
+ *
+ * Whether @directory should be hidden.
+ * For applications you want to call garcon_menu_directory_get_visible().
+ *
+ * Returns: a the hidden key for @directory.
+ */
 gboolean
 garcon_menu_directory_get_hidden (GarconMenuDirectory *directory)
 {
@@ -522,6 +617,16 @@ garcon_menu_directory_get_hidden (GarconMenuDirectory *directory)
 
 
 
+/**
+ * garcon_menu_directory_get_show_in_environment:
+ * @directory : a #GarconMenuDirectory
+ *
+ * Whether @directory is visible in the current environment
+ * which has been set by garcon_set_environment().
+ * For applications you want to call garcon_menu_directory_get_visible().
+ *
+ * Returns: %TRUE is visible in environment, else %FALSE.
+ */
 gboolean
 garcon_menu_directory_get_show_in_environment (GarconMenuDirectory *directory)
 {
@@ -560,6 +665,17 @@ garcon_menu_directory_get_show_in_environment (GarconMenuDirectory *directory)
 
 
 
+/**
+ * garcon_menu_directory_get_visible:
+ * @directory : a #GarconMenuDirectory
+ *
+ * Check which runs the following checks:
+ * garcon_menu_directory_get_show_in_environment(),
+ * garcon_menu_directory_get_hidden() and
+ * garcon_menu_directory_get_no_display().
+ *
+ * Returns: if visible %TRUE, else %FALSE.
+ **/
 gboolean
 garcon_menu_directory_get_visible (GarconMenuDirectory *directory)
 {
@@ -576,7 +692,15 @@ garcon_menu_directory_get_visible (GarconMenuDirectory *directory)
 }
 
 
-
+/**
+ * garcon_menu_directory_equal:
+ * @directory : a #GarconMenuDirectory
+ * @other : a #GarconMenuDirectory
+ *
+ * Checks if both directories point to the same file.
+ *
+ * Returns: if files are equal %TRUE, else %FALSE.
+ **/
 gboolean
 garcon_menu_directory_equal (GarconMenuDirectory *directory,
                              GarconMenuDirectory *other)
