@@ -1,6 +1,7 @@
 /* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
- * Copyright (c) 2006-2009 Jannis Pohlmann <jannis@xfce.org>
+ * Copyright (c) 2006-2010 Jannis Pohlmann <jannis@xfce.org>
+ * Copyright (c) 2009-2010 Nick Schermer <nick@xfce.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -85,6 +86,10 @@ static const gchar *garcon_menu_item_get_element_icon_name           (GarconMenu
 static gboolean     garcon_menu_item_get_element_visible             (GarconMenuElement      *element);
 static gboolean     garcon_menu_item_get_element_show_in_environment (GarconMenuElement      *element);
 static gboolean     garcon_menu_item_get_element_no_display          (GarconMenuElement      *element);
+static gboolean     garcon_menu_item_get_element_equal               (GarconMenuElement      *element,
+                                                                      GarconMenuElement      *other);
+static gboolean     garcon_menu_item_category_lists_equal            (GList                  *categories1,
+                                                                      GList                  *categories2);
 
 
 
@@ -384,6 +389,7 @@ garcon_menu_item_element_init (GarconMenuElementIface *iface)
   iface->get_visible = garcon_menu_item_get_element_visible;
   iface->get_show_in_environment = garcon_menu_item_get_element_show_in_environment;
   iface->get_no_display = garcon_menu_item_get_element_no_display;
+  iface->equal = garcon_menu_item_get_element_equal;
 }
 
 
@@ -622,6 +628,21 @@ garcon_menu_item_get_element_no_display (GarconMenuElement *element)
   return garcon_menu_item_get_no_display (GARCON_MENU_ITEM (element));
 }
 
+
+
+static gboolean
+garcon_menu_item_get_element_equal (GarconMenuElement *element,
+                                    GarconMenuElement *other)
+{
+  g_return_val_if_fail (GARCON_IS_MENU_ITEM (element), FALSE);
+  g_return_val_if_fail (GARCON_IS_MENU_ITEM (other), FALSE);
+
+  return g_file_equal (GARCON_MENU_ITEM (element)->priv->file, 
+                       GARCON_MENU_ITEM (other)->priv->file);
+}
+
+
+
 static const gchar*
 garcon_menu_item_get_element_name (GarconMenuElement *element)
 {
@@ -649,6 +670,33 @@ garcon_menu_item_get_element_icon_name (GarconMenuElement *element)
 
 
 
+static gboolean
+garcon_menu_item_category_lists_equal (GList *categories1,
+                                       GList *categories2)
+{
+  gboolean element_missing = FALSE;
+  GList   *lp;
+
+  guint size1;
+  guint size2;
+
+  size1 = g_list_length (categories1);
+  size2 = g_list_length (categories2);
+
+  if (size1 != size2)
+    return FALSE;
+
+  for (lp = categories1; !element_missing && lp != NULL; lp = lp->next)
+    {
+      if (g_list_find_custom (categories2, lp->data, (GCompareFunc) g_strcmp0) == NULL)
+        element_missing = TRUE;
+    }
+
+  return !element_missing;
+}
+
+
+
 GarconMenuItem *
 garcon_menu_item_new (GFile *file)
 {
@@ -800,12 +848,13 @@ garcon_menu_item_new_for_uri (const gchar *uri)
 
 gboolean
 garcon_menu_item_reload (GarconMenuItem  *item,
+                         gboolean        *affects_the_outside,
                          GError         **error)
 {
   g_return_val_if_fail (GARCON_IS_MENU_ITEM (item), FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-  return garcon_menu_item_reload_from_file (item, item->priv->file, error);
+  return garcon_menu_item_reload_from_file (item, item->priv->file, affects_the_outside, error);
 }
 
 
@@ -813,15 +862,22 @@ garcon_menu_item_reload (GarconMenuItem  *item,
 gboolean
 garcon_menu_item_reload_from_file (GarconMenuItem  *item,
                                    GFile           *file,
+                                   gboolean        *affects_the_outside,
                                    GError         **error)
 {
   GKeyFile *rc;
-  gchar    *contents;
-  gsize     length = 0;
-  gboolean  succeed;
-  gchar    *string;
   gboolean  boolean;
-  gchar    *name, *exec;
+  gboolean  succeed;
+  GList    *categories = NULL;
+  GList    *lp;
+  GList    *old_categories = NULL;
+  gchar   **mt;
+  gchar   **str_list;
+  gchar    *contents;
+  gchar    *string;
+  gchar    *name;
+  gchar    *exec;
+  gsize     length = 0;
 
   g_return_val_if_fail (GARCON_IS_MENU_ITEM (item), FALSE);
   g_return_val_if_fail (G_IS_FILE (file), FALSE);
@@ -912,6 +968,50 @@ garcon_menu_item_reload_from_file (GarconMenuItem  *item,
   boolean = GET_KEY (boolean, G_KEY_FILE_DESKTOP_KEY_HIDDEN);
   garcon_menu_item_set_hidden (item, boolean);
 
+  if (affects_the_outside != NULL)
+    {
+      /* create a deep copy the old categories list */
+      old_categories = g_list_copy (item->priv->categories);
+      for (lp = old_categories; lp != NULL; lp = lp->next)
+        lp->data = g_strdup (lp->data);
+    }
+
+  /* Determine the categories this application should be shown in */
+  str_list = GET_STRING_LIST (G_KEY_FILE_DESKTOP_KEY_CATEGORIES);
+  if (G_LIKELY (str_list != NULL))
+    {
+      for (mt = str_list; *mt != NULL; ++mt)
+        {
+          if (**mt != '\0')
+            categories = g_list_prepend (categories, g_strdup (*mt));
+        }
+
+      /* Free list */
+      g_strfreev (str_list);
+
+      /* Assign categories list to the menu item */
+      garcon_menu_item_set_categories (item, categories);
+    }
+  else
+    {
+      /* Assign empty categories list to the menu item */
+      garcon_menu_item_set_categories (item, NULL);
+    }
+
+  if (affects_the_outside != NULL)
+    {
+      if (!garcon_menu_item_category_lists_equal (old_categories, categories))
+        *affects_the_outside = TRUE;
+
+      g_list_foreach (old_categories, (GFunc) g_free, NULL);
+      g_list_free (old_categories);
+    }
+    
+
+  /* Set the rest of the private data directly */
+  item->priv->only_show_in = GET_STRING_LIST (G_KEY_FILE_DESKTOP_KEY_ONLY_SHOW_IN);
+  item->priv->not_show_in = GET_STRING_LIST (G_KEY_FILE_DESKTOP_KEY_NOT_SHOW_IN);
+
   /* Flush property notifications */
   g_object_thaw_notify (G_OBJECT (item));
 
