@@ -408,12 +408,9 @@ garcon_menu_merger_insert_default_dirs (GNode *parent,
       /* Build KDE data dir */
       kde_data_dir = g_build_filename (kde_dir, "share", base_name, NULL);
 
-      /* Add it as a directory dir if it exists */
-      if (G_LIKELY (g_file_test (kde_data_dir, G_FILE_TEST_IS_DIR)))
-        {
-          node = g_node_new (garcon_menu_node_create (type, kde_data_dir));
-          prev_node = g_node_insert_after (parent, prev_node, node);
-        }
+      /* Add it as a directory dir */
+      node = g_node_new (garcon_menu_node_create (type, kde_data_dir));
+      prev_node = g_node_insert_after (parent, prev_node, node);
 
       /* Free the KDE data dir */
       g_free (kde_data_dir);
@@ -421,26 +418,20 @@ garcon_menu_merger_insert_default_dirs (GNode *parent,
 
   /* The $KDEDIR workaround ends here */
 
-  /* Append system-wide data dirs */
+  /* Append system-wide data dirs, respecting the priority */
   dirs = g_get_system_data_dirs ();
   for (i = 0; dirs[i] != NULL; i++)
     {
       path = g_build_path (G_DIR_SEPARATOR_S, dirs[i], base_name, NULL);
-      if (G_LIKELY (g_file_test (path, G_FILE_TEST_IS_DIR)))
-        {
-          node = g_node_new (garcon_menu_node_create (type, path));
-          prev_node = g_node_insert_after (parent, prev_node, node);
-        }
+      node = g_node_new (garcon_menu_node_create (type, path));
+      g_node_insert_after (parent, prev_node, node);
       g_free (path);
     }
 
   /* Append user data dir */
   path = g_build_path (G_DIR_SEPARATOR_S, g_get_user_data_dir (), base_name, NULL);
-  if (G_LIKELY (g_file_test (path, G_FILE_TEST_IS_DIR)))
-    {
-      node = g_node_new (garcon_menu_node_create (type, path));
-      prev_node = g_node_insert_after (parent, prev_node, node);
-    }
+  node = g_node_new (garcon_menu_node_create (type, path));
+  prev_node = g_node_append (parent, node);
   g_free (path);
 }
 
@@ -473,28 +464,22 @@ garcon_menu_merger_insert_default_merge_dirs (GNode       *parent,
 
   prev_node = defaults_node;
 
-  /* Append system-wide config dirs */
+  /* Append system-wide config dirs, respecting the priority */
   dirs = g_get_system_config_dirs ();
   for (i = 0; dirs[i] != NULL; i++)
     {
       path = g_build_path (G_DIR_SEPARATOR_S, dirs[i], "menus", 
                            merge_dir_basename, NULL);
-      if (G_LIKELY (g_file_test (path, G_FILE_TEST_IS_DIR)))
-        {
-          node = g_node_new (garcon_menu_node_create (GARCON_MENU_NODE_TYPE_MERGE_DIR, path));
-          prev_node = g_node_insert_after (parent, prev_node, node);
-        }
+      node = g_node_new (garcon_menu_node_create (GARCON_MENU_NODE_TYPE_MERGE_DIR, path));
+      g_node_insert_after (parent, prev_node, node);
       g_free (path);
     }
 
   /* Append user config dir */
   path = g_build_path (G_DIR_SEPARATOR_S, g_get_user_config_dir (), "menus",
                        merge_dir_basename, NULL);
-  if (G_LIKELY (g_file_test (path, G_FILE_TEST_IS_DIR)))
-    {
-      node = g_node_new (garcon_menu_node_create (GARCON_MENU_NODE_TYPE_MERGE_DIR, path));
-      prev_node = g_node_insert_after (parent, prev_node, node);
-    }
+  node = g_node_new (garcon_menu_node_create (GARCON_MENU_NODE_TYPE_MERGE_DIR, path));
+  prev_node = g_node_append (parent, node);
   g_free (path);
 }
 
@@ -528,7 +513,7 @@ garcon_menu_merger_resolve_default_dirs (GNode                   *node,
 
       /* check if we have an application menu file */
       prefix = g_getenv ("XDG_MENU_PREFIX");
-      applications_filename = g_strconcat (prefix != NULL ? prefix : "", 
+      applications_filename = g_strconcat (prefix != NULL ? prefix : GARCON_DEFAULT_MENU_PREFIX, 
                                            "applications.menu", NULL);
       if (g_strcmp0 (filename, applications_filename) == 0)
         is_application_menu = TRUE;
