@@ -9,11 +9,11 @@
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
+ * You should have received a copy of the GNU Library General
+ * Public License along with this library; if not, write to the
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
@@ -275,12 +275,14 @@ garcon_menu_parser_run (GarconMenuParser *parser,
 
       if (error != NULL)
         {
-          g_warning (_("Could not load menu file data from %s: %s"),
+          g_message (_("Could not load menu file data from %s: %s"),
                      uri, (*error)->message);
           g_error_free (*error);
         }
       else
-        g_warning (_("Could not load menu file data from %s"), uri);
+        {
+          g_message (_("Could not load menu file data from %s"), uri);
+        }
 
       g_free (uri);
       return FALSE;
